void makePlot(int iShow){

  gROOT->Reset();
  gROOT->SetStyle("Plain");
  gStyle->SetOptStat(0);
  char  hId[120];
  char  fString[120];
  char  tString[120];

  //connect to histo file
  sprintf(fString,"./myOutFile.root");
  TFile *hFile1 = new TFile(fString);

  //sprintf(hId,"hMassRhoT%dE%d",tBin,eBin);

  TH1D *hMassFull; hFile1->GetObject("hMass",hMassFull);
  hMassFull->SetName("hMassFull");

  TH2D *h2d; hFile1->GetObject("hEvsCosWithMassCut",h2d);
  h2d->SetName("h2d");

  
  //Make a canvas
  TCanvas * c1 = new TCanvas("c1","Me canvas title");

  //For info on colors, fill styles, etc.. https://root.cern.ch/doc/master/classTAttFill.html
  //For text stuff see https://root.cern.ch/doc/master/classTAttText.html

  if (iShow == 1){
    //Draw full histogram
    hMassFull->Draw();


    hMassFull->GetXaxis()->SetTitle("Mass (GeV)");
    hMassFull->GetYaxis()->SetTitle("Counts");
    hMassFull->SetLineColor(1);



    //Make center portion of histogram and make fill green
    TH1D * hMass1 = (TH1D *)hMassFull->Clone("hMass1");
    hMass1->GetXaxis()->SetRangeUser(0.4,0.6);
    hMass1->SetFillStyle(3001);
    hMass1->SetFillColor(3);
    hMass1->SetLineColor(1);

    //Make left-side of histogram and make fill red
    TH1D * hMass2 = (TH1D *)hMassFull->Clone("hMass2");
    hMass2->GetXaxis()->SetRangeUser(0.0,0.4);
    hMass2->SetFillStyle(3001);
    hMass2->SetFillColor(2);
    hMass2->SetLineColor(1);

    //Make right-side of histogram and make fill red
    TH1D * hMass3 = (TH1D *)hMassFull->Clone("hMass3");
    hMass3->GetXaxis()->SetRangeUser(0.6,1.0);
    hMass3->SetFillStyle(3001);
    hMass3->SetFillColor(2);
    hMass3->SetLineColor(1);

    //Draw center, left and right
    hMass1->Draw("samehist");
    hMass2->Draw("samehist");
    hMass3->Draw("samehist");

    //Draw some text
    int intVal = 1098;
    double floatVal = 3.14159;

    sprintf(tString,"I am a string with integer = %d and float = %f ",intVal,floatVal);
    TLatex *t1 = new TLatex();
    t1->SetNDC();//Make the dimensions as fractions of histogram 
    t1->SetTextSize(0.05);
    double xLocationFraction = 0.1;
    double yLocationFraction = 0.93;
    t1->DrawLatex(xLocationFraction,yLocationFraction,tString);


    sprintf(tString,"3 sig fig float = %3.2f ",floatVal);
    TLatex *t2 = new TLatex();
    t2->SetNDC();
    t2->SetTextSize(0.05);
    t2->DrawLatex(0.15,0.8,tString);

    sprintf(tString,"Small greek symbol float:#sigma = %3.2f ",floatVal);
    TLatex *t3 = new TLatex();
    t3->SetNDC();
    t3->SetTextSize(0.03);
    t3->DrawLatex(0.55,0.8,tString);

    sprintf(tString,"Super- and sub-script stuff E_{#gamma}^{2} = 2^{2} (GeV)^{2}");
    TLatex *t4 = new TLatex();
    t4->SetNDC();
    t4->SetTextSize(0.03);
    t4->DrawLatex(0.1,0.7,tString);

    //Preliminary
    TLatex *t5 = new TLatex();
    t5->SetNDC();
    t5->SetTextSize(0.2);
    t5->SetTextAngle(30);
    t5->SetTextColor(4);
    t5->DrawLatex(0.2,0.2,"Preliminary");
    hMass1->Draw("histsame");// Redraw over the text

    //Make a legend with fill type
    Double_t xl1=0.55, yl1 = 0.3;
    Double_t yl2=yl1 + 0.18;
    Double_t xl2=xl1 + 0.2;
    TLegend *legend = new TLegend(xl1,yl1,xl2,yl2);
    legend->SetFillColor(0);
    legend->SetLineColor(0);
    legend->SetTextSize(0.035);
    legend->AddEntry(hMass1,"Center","f");//Here "f" is for fill type
    legend->AddEntry(hMass2,"Sides","f");
    legend->Draw();
    //return;
    c1->Print("./pics/ex1.png");
  } 
  if (iShow == 2){
    h2d->Draw("colz");
    h2d->GetXaxis()->SetTitle("Cos(#theta_{c.m.})");
    h2d->GetYaxis()->SetTitle("E_{#gamma} (GeV)");
    c1->Print("./pics/ex2.png");
  }
}
